/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { aws_bedrock as bedrock } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export declare enum FiltersConfigType {
    VIOLENCE = "VIOLENCE",
    HATE = "HATE",
    INSULTS = "INSULTS",
    MISCONDUCT = "MISCONDUCT",
    PROMPT_ATTACK = "PROMPT_ATTACK",
    SEXUAL = "SEXUAL"
}
export declare enum FiltersConfigStrength {
    NONE = "NONE",
    LOW = "LOW",
    MEDIUM = "MEDIUM",
    HIGH = "HIGH"
}
export declare enum ContextualGroundingFilterConfigType {
    /**Grounding score represents the confidence that the model response is factually correct and grounded in the source.
     * If the model response has a lower score than the defined threshold, the response will be blocked and the configured
     * blocked message will be returned to the user. A higher threshold level blocks more responses. */
    GROUNDING = "GROUNDING",
    /**Relevance score represents the confidence that the model response is relevant to the user's query.
     * If the model response has a lower score than the defined threshold, the response will be blocked and
     * the configured blocked message will be returned to the user. A higher threshold level blocks more responses */
    RELEVANCE = "RELEVANCE"
}
export interface ContentPolicyConfigProps {
    readonly filtersConfigType: FiltersConfigType;
    readonly inputStrength?: FiltersConfigStrength;
    readonly outputStrength?: FiltersConfigStrength;
}
export interface ContextualGroundingPolicyConfigProps {
    /**The filter details for the guardrails contextual grounding filter.
     * GROUNDING: Validate if the model responses are grounded and factually correct based on the information provided in the reference source,
     * and block responses that are below the defined threshold of grounding.
     * RELEVANCE: Validate if the model responses are relevant to the user's query and block responses
     * that are below the defined threshold of relevance.
    */
    readonly filtersConfigType: ContextualGroundingFilterConfigType;
    /** The threshold details for the guardrails contextual grounding filter.
     * 0 blocks nothing, 0.99 blocks almost everything
    */
    readonly threshold: number;
}
export declare class ContentPolicyConfig extends Construct {
    readonly contentPolicyConfigList: bedrock.CfnGuardrail.ContentFilterConfigProperty[];
    constructor(scope: Construct, id: string, props?: ContentPolicyConfigProps[]);
    private createContentPolicyConfigList;
    private createContentFilterConfig;
}
